#
# Tobias Grimm <tg@e-tobi.net> 
#
# Some functions for database management, sourced by postinst.
#

check_params()
{
    if [ -z "$dbserver" ] ; then
        error="No database server specified."
    elif [ -z "$dbadmin" ] ; then
        error="No database administrator specified."
    elif [ -z "$dbdatabase" ] ; then
       error="No database name specified."
    else
        return 0
    fi
    return 1
}

build_mysqlcmd()
{
    MYSQLCMD="mysql --host=$dbserver --user=$dbadmin"

    if [ -n "$dbadminpass" ] ; then
        MYSQLCMD="$MYSQLCMD \"--password=$dbadminpass\""
    fi
    if [ -n "$dbport" ] ; then
        MYSQLCMD="$MYSQLCMD \"--port=$dbport\""
    fi
}

check_server()
{
    if ! check_params ; then
        return 1
    fi

    build_mysqlcmd

    if ! eval $MYSQLCMD </dev/null >/dev/null 2>&1 ; then
        error="Error when trying to connect to the mysql database."
        return 1
    fi
    return 0
}

check_database()
{
    if ! eval $MYSQLCMD -f -B -e "\"show databases;\"" | \
      grep -e "^$dbdatabase$" > /dev/null 2>&1 ; then
        return 1
    fi
    return 0
}

check_user()
{
    if ! eval $MYSQLCMD -f mysql -e \
      "\"SELECT User from user where User='$dbuser';\"" | \
      grep -e "^$dbuser$" > /dev/null 2>&1 ; then
        return 1
    fi
    return 0
}

create_database()
{
    if ! check_database ; then
        if eval $MYSQLCMD -f -e "\"CREATE DATABASE $dbdatabase;\"" ; then
            if ! eval $MYSQLCMD -f -B -e "\"show databases;\"" | \
              grep -e "^$dbdatabase$" > /dev/null 2>&1 ; then
                error="Database $dbdatabase NOT successfully created. "\
                  "You have to do it manually."
                return 1
            fi
        else
            error="Unable to create database."
            return 1
        fi
    fi
    return 0
}

create_user()
{
    local script

    script="
    GRANT ALL PRIVILEGES ON \`$dbdatabase\`.* TO \`$dbuser\`@'%'
            IDENTIFIED BY '$dbuserpass';
    GRANT ALL PRIVILEGES ON \`$dbdatabase\`.* TO \`$dbuser\`@localhost
            IDENTIFIED BY '$dbuserpass';
    flush privileges;"
    
    if eval $MYSQLCMD -f mysql -e '"$script"'  ; then
        if ! eval $MYSQLCMD -f mysql -e '"select User from user;"' | \
          grep $dbuser >/dev/null 2>&1 ; then
            error="Database user $dbuser NOT successfully added."
            return 1
        fi
    else
        error="Unable to create user."
        return 1
    fi
    return 0
}

purge_database()
{
    if eval $MYSQLCMD -f -e "\"DROP DATABASE IF EXISTS $dbdatabase;\"" ; then
        if check_database ; then
            error="Database $dbdatabase NOT successfully droped." 
            return 1
        fi
    else
        error="Unable to drop database."
        return 1
    fi
    return 0
}

purge_user()
{
    if check_user ; then
        if eval $MYSQLCMD -f mysql -e \
          "\"DELETE FROM user where User='$dbuser';\"" ; then
            if check_user ; then
                error="User $dbuser NOT successfully deleted." 
                return 1
            fi
        else
            error="Unable to delete user."
            return 1
        fi
    fi
    return 0
}
